@@ -897,7 +897,7 @@ static ngx_int_t ngx_streaming_handler(ngx_http_request_t *r)
 
   if(r->method & NGX_HTTP_DELETE && is_rest_api)
   {
-    http_status = mp4_api_process(context, http_method, filename);
+    http_status = mp4_channel_api(context, http_method, filename, "");
     r->headers_out.content_length_n = 0;
     r->headers_out.status = http_status;
     r->header_only = 1;
@@ -1090,7 +1090,7 @@ ngx_streaming_handler_post(ngx_http_request_t *r, mp4_process_context_t* ctx,
                 filename);
 
   post_handler_t* post_handler = is_rest_api ?
-    create_post_handler_api(ctx, http_method, filename) :
+    create_post_handler_api(ctx, http_method, filename, "") :
       create_post_handler(ctx, filename);
 
   if(post_handler == NULL)
@@ -1199,7 +1199,7 @@ ngx_streaming_handler_get(ngx_http_request_t *r,
 
   {
     r->headers_out.status = http_status = is_rest_api ?
-      mp4_api_process(context, http_method, filename) :
+      mp4_channel_api(context, http_method, filename, "") :
         mp4_process(context, http_method, filename);
 
     headers_t* headers = mp4_process_context_get_headers(context);
